Getting Started — Startup Name Generator (sng) 0.2 documentation

# Getting Started

    In [2]:

    # While the sng package is not installed, add the package's path
    # (the parent directory) to the library path:

    import os
    import sys
    sys.path.insert(0, os.path.abspath('../../'))

    In [3]:

    import sng

    /usr/local/lib/python3.6/dist-packages/h5py/__init__.py:36: FutureWarning: Conversion of the second argument of issubdtype from `float` to `np.floating` is deprecated. In future, it will be treated as `np.float64 == np.dtype(float).type`.
      from ._conv import register_converters as _register_converters
    Using TensorFlow backend.